@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '3.20';
+our $VERSION = '3.30';
 
 # AUTHORITY
 
@@ -39,6 +39,7 @@ sub import {
     cli => 1,
     code => 1,
     config => 1,
+    container => 1,
     cop => 1,
     data => 1,
     date => 1,
@@ -68,8 +69,10 @@ sub import {
     perl => 1,
     process => 1,
     proto => 1,
+    puts => 1,
     raise => 1,
     random => 1,
+    range => 1,
     regexp => 1,
     replace => 1,
     render => 1,
@@ -315,6 +318,18 @@ sub config ($;$@) {
   return Venus::Config->new($data)->$code(@args);
 }
 
+sub container ($;$@) {
+  my ($data, $code, @args) = @_;
+
+  require Venus::Container;
+
+  if (!$code) {
+    return Venus::Container->new($data);
+  }
+
+  return Venus::Container->new($data)->$code(@args);
+}
+
 sub cop (@) {
   my ($data, @args) = @_;
 
@@ -641,6 +656,23 @@ sub proto ($;$@) {
   return Venus::Prototype->new($data)->$code(@args);
 }
 
+sub puts ($;@) {
+  my ($data, @args) = @_;
+
+  $data = cast($data);
+
+  my $result = [];
+
+  if ($data->isa('Venus::Hash')) {
+    $result = $data->puts(@args);
+  }
+  elsif ($data->isa('Venus::Array')) {
+    $result = $data->puts(@args);
+  }
+
+  return wantarray ? (@{$result}) : $result;
+}
+
 sub raise ($;$) {
   my ($self, $data) = @_;
 
@@ -670,6 +702,12 @@ sub random (;$@) {
   return $random->$code(@args);
 }
 
+sub range ($;@) {
+  my ($data, @args) = @_;
+
+  return array($data, 'range', @args);
+}
+
 sub regexp ($;$@) {
   my ($data, $code, @args) = @_;
 
@@ -1003,7 +1041,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-3.20
+3.30
 
 =cut
 
@@ -2024,6 +2062,59 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 container
+
+  container(HashRef $value, Str | CodeRef $code, Any @args) (Any)
+
+The container function builds and returns a L<Venus::Container> object, or
+dispatches to the coderef or method provided.
+
+I<Since C<3.20>>
+
+=over 4
+
+=item container example 1
+
+  package main;
+
+  use Venus 'container';
+
+  my $container = container {};
+
+  # bless({...}, 'Venus::Config')
+
+=back
+
+=over 4
+
+=item container example 2
+
+  package main;
+
+  use Venus 'container';
+
+  my $data = {
+    '$metadata' => {
+      tmplog => "/tmp/log"
+    },
+    '$services' => {
+      log => {
+        package => "Venus/Path",
+        argument => {
+          '$metadata' => "tmplog"
+        }
+      }
+    }
+  };
+
+  my $log = container $data, 'resolve', 'log';
+
+  # bless({value => '/tmp/log'}, 'Venus::Path')
+
+=back
+
+=cut
+
 =head2 cop
 
   cop(Str | Object | CodeRef $self, Str $name) (CodeRef)
@@ -3559,6 +3650,44 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 range
+
+  range(Int | Str @args) (ArrayRef)
+
+The range function returns the result of a L<Venus::Array/range> operation.
+
+I<Since C<3.20>>
+
+=over 4
+
+=item range example 1
+
+  package main;
+
+  use Venus 'range';
+
+  my $range = range [1..9], ':4';
+
+  # [1..5]
+
+=back
+
+=over 4
+
+=item range example 2
+
+  package main;
+
+  use Venus 'range';
+
+  my $range = range [1..9], '-4:-1';
+
+  # [6..9]
+
+=back
+
+=cut
+
 =head2 regexp
 
   regexp(Str $value, Str | CodeRef $code, Any @args) (Any)
