@@ -362,6 +362,36 @@ sub path {
   return wantarray ? ($self->find(@path)) : $self->find(@path);
 }
 
+sub puts {
+  my ($self, @args) = @_;
+
+  my $result = [];
+
+  require Venus::Array;
+
+  for (my $i = 0; $i < @args; $i += 2) {
+    my ($into, $path) = @args[$i, $i+1];
+
+    next if !defined $path;
+
+    my $value;
+    my @range;
+
+    ($path, @range) = @{$path} if ref $path eq 'ARRAY';
+
+    $value = $self->path($path);
+    $value = Venus::Array->new($value)->range(@range) if ref $value eq 'ARRAY';
+
+    if (ref $into eq 'SCALAR') {
+      $$into = $value;
+    }
+
+    CORE::push @{$result}, $value;
+  }
+
+  return wantarray ? (@{$result}) : $result;
+}
+
 sub random {
   my ($self) = @_;
 
@@ -2812,6 +2842,120 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 puts
+
+  puts(Any @args) (ArrayRef)
+
+The puts method select values from within the underlying data structure using
+L<Venus::Hash/path>, optionally assigning the value to the preceeding scalar
+reference and returns all the values selected.
+
+I<Since C<3.20>>
+
+=over 4
+
+=item puts example 1
+
+  package main;
+
+  use Venus::Hash;
+
+  my $hash = Venus::Hash->new({
+    size => "small",
+    fruit => "apple",
+    meta => {
+      expiry => '5d',
+    },
+    color => "red",
+  });
+
+  my $puts = $hash->puts(undef, 'fruit', undef, 'color');
+
+  # ["apple", "red"]
+
+=back
+
+=over 4
+
+=item puts example 2
+
+  package main;
+
+  use Venus::Hash;
+
+  my $hash = Venus::Hash->new({
+    size => "small",
+    fruit => "apple",
+    meta => {
+      expiry => '5d',
+    },
+    color => "red",
+  });
+
+  $hash->puts(\my $fruit, 'fruit', \my $expiry, 'meta.expiry');
+
+  my $puts = [$fruit, $expiry];
+
+  # ["apple", "5d"]
+
+=back
+
+=over 4
+
+=item puts example 3
+
+  package main;
+
+  use Venus::Hash;
+
+  my $hash = Venus::Hash->new({
+    size => "small",
+    fruit => "apple",
+    meta => {
+      expiry => '5d',
+    },
+    color => "red",
+  });
+
+  $hash->puts(
+    \my $fruit, 'fruit',
+    \my $color, 'color',
+    \my $expiry, 'meta.expiry',
+    \my $ripe, 'meta.ripe',
+  );
+
+  my $puts = [$fruit, $color, $expiry, $ripe];
+
+  # ["apple", "red", "5d", undef]
+
+=back
+
+=over 4
+
+=item puts example 4
+
+  package main;
+
+  use Venus::Hash;
+
+  my $hash = Venus::Hash->new({set => [1..20]});
+
+  $hash->puts(
+    \my $a, 'set.0',
+    \my $b, 'set.1',
+    \my $m, ['set', '2:-2'],
+    \my $x, 'set.18',
+    \my $y, 'set.19',
+  );
+
+  my $puts = [$a, $b, $m, $x, $y];
+
+  # [1, 2, [3..18], 19, 20]
+
+=back
+
+=cut
+
 =head2 random
 
   random() (Any)
