@@ -610,7 +610,7 @@ sub registrants {
   $path = $path->child($self->exchange) if $self->exchange;
 
   my $result = [
-    map /(\d+)/, grep /(\d+)\.\1$/, CORE::glob($path->child('*.*')->absolute)
+    map /(\d+)$/, grep /(\d+)\.\1$/, CORE::glob($path->child('*.*')->absolute)
   ];
 
   return wantarray ? @{$result} : $result;
